# import the necessary modules
from pyees.variable import variable
from pyees.fit import dummy_fit, pol_fit, lin_fit, exp_fit, pow_fit, logistic_fit
from pyees.sheet import sheetsFromFile, fileFromSheets, sheet
from pyees.prop import prop
from pyees.solve import solve
from pyees.unit import addNewUnit



    